==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Bem-vindo @nom@ !',
	'c_accueil_configurer_site' => 'Configurar o seu sítio',
	'c_accueil_configurer_site_texte' => 'Uma das primeiras coisas a fazer é dar um nome ao seu sítio.
		O nome é actualmente « @nom@ ». O nome do sítio é exibido no topo desta página.
		Clicando nele, pode alterá-lo, mas também atribuir-lhe um logotipo e um slogan.',
	'c_accueil_publication' => 'Publique !',
	'c_accueil_publication_texte' => 'Para publicar uma página, precisa de criar um artigo. Para tal é necessário criar pelo menos uma rubrica. Pode fazê-lo clicando no menu "Edição" e depois em "Rubricas".',
	'c_accueil_texte' => 'Acabou de entrar na área privda de SPIP.',
	'c_accueil_texte_revenir' => 'Esta página apresenta a última actividade editorial no seu sítio. Pode visitá-la a qualquer momento, clicando no "ícone casa", no topo, abaixo do seu nome de utilizador.', # MODIF
	'c_article_redaction' => 'O artigo está em edição',
	'c_article_redaction_redacteur' => 'O artigo está em edição',
	'c_article_redaction_redacteur_texte' => 'Para propor o seu artigo aos administradores do sítio e aos outros redactores, no bloco ao lado da coluna, altere "Redacção em curso" para "Proposto para avaliação".',
	'c_article_redaction_texte' => 'Para publicar este artigo no sítio público, precisa de alterar o seu estatuto. No bloco do lado da coluna, altere "Redacção em curso" para "Publicado online".',
	'c_articles_creer' => 'Como criar um artigo?',
	'c_articles_creer_texte' => 'Não pode criar um artigo a partir desta página, se não tiver pelo menos uma rubrica no seu sítio. Pode criá-la através do menu "Rubricas", clicando em "Editar".',
	'c_job' => 'Tarefas a realizar…',
	'c_job_texte' => 'Esta página lista as tarefas de manutenção a realizar por SPIP. Essas tarefas são executadas em intervalos regulares ou ocasionalmente, para processamentos pesados necessários para os plugins, como o envio de e-mails em massa.',
	'c_rubrique_publier' => 'Crie um artigo',
	'c_rubrique_publier_texte' => 'Uma rubrica é visível no sítio público apenas a partir do momento em que contém algum conteúdo publicado (por exemplo, um artigo publicado). Portanto, crie um artigo. Pode fazê-lo a partir desta página, abaixo da descrição da sua rubrica.',
	'c_rubriques_creer' => 'Crie a primeira rubrica !',
	'c_rubriques_creer_texte' => 'LAs rubricas são a estrutura básica do sítio. Pode criar artigos em cada uma delas. Comece por criar uma primeira rubrica.',

	// E
	'explication_activer_compagnon' => 'O guia adiciona comentários em algumas páginas da área privada, para ajudar a trabalhar com SPIP. Deseja activá-lo?',
	'explication_reinitialiser_compagnon' => 'As mensagens já visualizadas por um autor não serão exibidas. Deseja reiniciar essas mensagens?',

	// L
	'label_activer_compagnon' => 'Activar o guia ?',
	'label_reinitialiser_compagnon' => 'Reiniciar as mensagens do guia ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bem !',
	'ok_jai_compris' => 'Compreendi !',
	'ok_merci' => 'Obrigado',
	'ok_parfait' => 'Perfeito !',

	// R
	'reinitialisation' => 'Reiniciar',
	'reinitialisation_ok' => 'O reinício foi efectuado.',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sim, unicamente as que já li',
	'reinitialiser_tous' => 'Sim, qualquer que seja o autor',

	// T
	'titre_compagnon' => 'O guia',
	'titre_page_configurer_compagnon' => 'Configurar o guia'
);

==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Ocultar todas as mensagens do companheiro', # RELIRE
	'bouton_tout_compris_explication' => 'Se você já conhece o SPIP, pode optar por ignorar todas as mensagens do Companheiro; caso contrário, cada mensagem pode ser fechada individualmente.', # RELIRE

	// C
	'c_accueil_bienvenue' => 'Bem-vindo @nom@ !',
	'c_accueil_configurer_site' => 'Configurar o seu sítio',
	'c_accueil_configurer_site_texte' => 'Uma das primeiras coisas a fazer é dar um nome ao seu sítio.
		O nome é actualmente « @nom@ ». O nome do sítio é exibido no topo desta página.
		Clicando nele, pode alterá-lo, mas também atribuir-lhe um logotipo e um slogan.',
	'c_accueil_publication' => 'Publique !',
	'c_accueil_publication_texte' => 'Para publicar uma página, precisa de criar um artigo. Para tal é necessário criar pelo menos uma rubrica. Pode fazê-lo clicando no menu "Edição" e depois em "Rubricas".',
	'c_accueil_texte' => 'Acabou de entrar na área privda de SPIP.',
	'c_accueil_texte_revenir' => 'Esta página apresenta a última actividade editorial no seu sítio. Pode visitá-la a qualquer momento, clicando no "ícone casa", no topo, abaixo do seu nome de utilizador.', # MODIF
	'c_article_redaction' => 'O artigo está em edição',
	'c_article_redaction_redacteur' => 'O artigo está em edição',
	'c_article_redaction_redacteur_texte' => 'Para propor o seu artigo aos administradores do sítio e aos outros redactores, no bloco ao lado da coluna, altere "Redacção em curso" para "Proposto para avaliação".',
	'c_article_redaction_texte' => 'Para publicar este artigo no sítio público, precisa de alterar o seu estatuto. No bloco do lado da coluna, altere "Redacção em curso" para "Publicado online".',
	'c_articles_creer' => 'Como criar um artigo?',
	'c_articles_creer_texte' => 'Não pode criar um artigo a partir desta página, se não tiver pelo menos uma rubrica no seu sítio. Pode criá-la através do menu "Rubricas", clicando em "Editar".',
	'c_job' => 'Tarefas a realizar…',
	'c_job_texte' => 'Esta página lista as tarefas de manutenção a realizar por SPIP. Essas tarefas são executadas em intervalos regulares ou ocasionalmente, para processamentos pesados necessários para os plugins, como o envio de e-mails em massa.',
	'c_rubrique_publier' => 'Crie um artigo',
	'c_rubrique_publier_texte' => 'Uma rubrica é visível no sítio público apenas a partir do momento em que contém algum conteúdo publicado (por exemplo, um artigo publicado). Portanto, crie um artigo. Pode fazê-lo a partir desta página, abaixo da descrição da sua rubrica.',
	'c_rubriques_creer' => 'Crie a primeira rubrica !',
	'c_rubriques_creer_texte' => 'LAs rubricas são a estrutura básica do sítio. Pode criar artigos em cada uma delas. Comece por criar uma primeira rubrica.',
	'c_sites_creer' => 'Como criar ou importar um site ?',
	'c_sites_creer_texte' => 'Você só poderá criar ou importar um sítio com base nesta página
somente se já criou uma seção Rubrica em seu sítio.
Você pode criá-lo no menu “Editar” e, em seguida, em “Itens”.', # MODIF

	// E
	'explication_activer_compagnon' => 'O guia adiciona comentários em algumas páginas da área privada, para ajudar a trabalhar com SPIP. Deseja activá-lo?',
	'explication_reinitialiser_compagnon' => 'As mensagens já visualizadas por um autor não serão exibidas. Deseja reiniciar essas mensagens?',

	// L
	'label_activer_compagnon' => 'Activar o guia ?',
	'label_reinitialiser_compagnon' => 'Reiniciar as mensagens do guia ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bem !',
	'ok_jai_compris' => 'Compreendi !',
	'ok_merci' => 'Obrigado',
	'ok_parfait' => 'Perfeito !',

	// R
	'reinitialisation' => 'Reiniciar',
	'reinitialisation_ok' => 'O reinício foi efectuado.',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sim, unicamente as que já li',
	'reinitialiser_tous' => 'Sim, qualquer que seja o autor',

	// T
	'titre_compagnon' => 'O guia',
	'titre_page_configurer_compagnon' => 'Configurar o guia'
);
